=====================================
Ocetrac
=====================================

.. image:: https://github.com/ocetrac/ocetrac/workflows/Tests/badge.svg
   :target: https://github.com/ocetrac/ocetrac/actions

.. image:: https://codecov.io/gh/ocetrac/ocetrac/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/ocetrac/ocetrac
   
.. image:: https://img.shields.io/badge/License-MIT-lightgray.svg?style=flt-square
   :target: https://opensource.org/licenses/MIT

.. image:: https://img.shields.io/pypi/v/ocetrac.svg
   :target: https://pypi.org/project/ocetrac
   
.. image:: https://img.shields.io/conda/dn/conda-forge/ocetrac?label=conda-forge
   :target: https://anaconda.org/conda-forge/ocetrac
   
.. image:: https://readthedocs.org/projects/ocetrac/badge/?version=latest
   :target: https://ocetrac.readthedocs.io/en/latest/?badge=latest 
   
.. image:: https://dev.azure.com/conda-forge/feedstock-builds/_apis/build/status/ocetrac-feedstock?branchName=master
   :target: https://dev.azure.com/conda-forge/feedstock-builds/_build/latest?definitionId=13414&branchName=maste 


|
Ocetrac is a Python 3.6+ package designed to label and track the evolution of unique geospatial features in gridded datasets. The package is designed to accept data that have already been preprocessed, meaning that the data only contain values the user is interested in tracking. Ocetrac operates lazily with Dask so that it is memory uninhibited and fast through parallelized execution. We provide examples and demonstrate best practices as developed by the Climate Data Science Lab at Columbia University. Here you will find instructions on how to install ocetrac, use it's API, and contribute to future releases.  

For recommendations or bug reports, please visit: https://github.com/ocetrac/ocetrac/issues/new

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   installation
   dependencies
   examples
   
.. toctree::
   :maxdepth: 2
   :caption: Users Guide

.. toctree::
   :maxdepth: 2
   :caption: Help and Reference

   SciPy 2021 Talk <https://ocetrac.github.io/scipy2021-talk/#/>
   GitHub Repo <https://github.com/ocetrac/ocetrac>
   api
   authors
   contributing
   wishlist
   
